pm4py.algo.enhancement.roles package
====================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.enhancement.roles.common
   pm4py.algo.enhancement.roles.variants

Submodules
----------

pm4py.algo.enhancement.roles.algorithm module
---------------------------------------------

.. automodule:: pm4py.algo.enhancement.roles.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.enhancement.roles
   :members:
   :undoc-members:
   :show-inheritance:
